<?php

namespace Drupal\employee\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * EmployeeListControllerクラス
 */
class EmployeeListController extends ControllerBase {

  /**
   *  employeeテーブルからのリストの取得
   */
  function queryEmployeeList($header, $employee_id, $dept_code) {

    // employeeテーブルのqueryを行う
    $query = \Drupal::database()->select('employee', 'emp');
    $query->fields('emp', ['employee_id','dept_code','name','kana','position','telephone','mail']);
    // ヘッダーにソート項目を指定
    $table_sort = $query->extend('Drupal\Core\Database\Query\TableSortExtender')->orderByHeader($header);
    // ページャーを使用。表示件数：5行
    $pager = $table_sort->extend('Drupal\Core\Database\Query\PagerSelectExtender')->limit(5);

    // フィルターとして社員IDが入力された場合は、検索条件にemployee_idを追加する
    if ( !empty($employee_id) ) {
      $pager->condition('employee_id', $employee_id);
    }
    // フィルターとして部門コードが入力された場合は、検索条件にLIKEでdept_codeを追加する
    if ( !empty($dept_code) ) {
      $pager->condition('dept_code', '%' . $dept_code . '%', 'LIKE');
    }

    // 検索の実行
    $results = $pager->execute()->fetchAll();

    // 出力用の配列を初期化
    $output = array();

    // query結果を出力用の配列にセット
    foreach ($results as $row) {

      // 表示画面へのリンク
      $view = Url::fromRoute('employee.view',['employee_id' => $row->employee_id] );
      $name_link = \Drupal::l($row->name, $view); 

      // 編集画面、削除画面へのリンク
      $edit = Url::fromRoute('employee.update',['employee_id' => $row->employee_id] );
      $delete = Url::fromRoute('employee.delete',['employee_id' => $row->employee_id] );

//    Drupal::l はDeprecated のため、Link::fromTextAndUrlを使用するべきのようだが、以下のコードだとエラーになるため
//    今回は、Drupal::l を使用する
//    $edit_link = Link::fromTextAndUrl('編集', $edit);
//    $delete_link = Link::fromTextAndUrl('削除', $delete);
      $edit_link = \Drupal::l('編集', $edit);
      $delete_link = \Drupal::l('削除', $delete);

      $opeLink = t('@linkEdit  @linkDelete', array('@linkEdit' => $edit_link, '@linkDelete' => $delete_link));


      $output[] = [
        'employee_id' => $row->employee_id,
        'dept_code' => $row->dept_code,
        'name' => $name_link,
        'kana' => $row->kana,
        'position' => $row->position,
        'telephone' => $row->telephone,
        'mail' => $row->mail,
        'opt' => $opeLink,
      ];
    }

    return $output;
  }

  /**
   * employeeテーブルの一覧表示
   *
   * @return array
   *   Return markup array.
   */
  public function list() {

    // フィルターFormからのパラメータの取得  
    $employee_id = \Drupal::request()->query->get('employee_id');
    $dept_code = \Drupal::request()->query->get('dept_code');
    // ゼロパディング
    if ( !empty($employee_id) ) {
      $employee_id = sprintf('%05d',$employee_id);
    }
	
    //filter controllerの読み込み
    $form['form'] = $this->formBuilder()->getForm('Drupal\employee\Form\EmployeeFilterForm');


    // 社員の追加
    $form['employee'] = [
      '#title' => $this->t('社員の追加'),
      '#type' => 'link',
      '#url' => Url::fromRoute('employee.add'),
      '#attributes' => [
        'class' => ['link-btn'],
      ]
    ];


    // 'field'で指定された項目がソート項目となる
    $header = [
      [ 'data' => '社員ID',     'field' => 'employee_id', 'sort' => 'asc' ],
      [ 'data' => '部門コード', 'field' => 'dept_code' ],
      [ 'data' => '名前',       ],
      [ 'data' => 'カナ',       'field' => 'kana' ],
      [ 'data' => '職位',       ],
      [ 'data' => '電話',       ],
      [ 'data' => 'メール',     ],
      [ 'data' => '操作',       ], 
    ];

    $output = $this->queryEmployeeList($header, $employee_id, $dept_code);

    $form['table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $output,
      '#empty' => 'データがありません',
    ];

    // pagerの表示
    $form['pager'] = [
      '#type' => 'pager'    
    ];

    return $form;
  }

}

