<?php
/**
 * @file
 * Contains \Drupal\employee\Form\EmployeeAddForm.
 */
namespace Drupal\employee\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Url;

class EmployeeAddForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'employee_add_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {


    $form['employee_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('社員ID'),
      '#required' => TRUE,
    );

    $form['dept_code'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('部門コード'),
      '#required' => TRUE,
    );

    $form['name'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('名前'),
      '#required' => TRUE,
    );

    $form['kana'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('カナ'),
      '#required' => TRUE,
    );

    $form['position'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('職位'),
      '#required' => TRUE,
    );

    $form['telephone'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('電話')
    );

    $form['mail'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('メール')
    );

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('保存'),
      '#button_type' => 'primary',
    );
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    // 入力された'employee_id'がすでに存在しているかを確認
    $employee_id = $form_state->getValue('employee_id');
    $conn = Database::getConnection();
    $query = $conn->select('employee', 'emp');
    $query->condition('employee_id', $employee_id)->fields('emp');;
    $record = $query->execute()->fetchAssoc();

    // エラーメッセージの出力
    if ( 5 != strlen($form_state->getValue('employee_id')) ) {
      $form_state->setErrorByName('employee_id', '社員IDは５文字で入力して下さい。');
    } else if ( $record ) {
      $form_state->setErrorByName('employee_id', '入力された社員IDはすでに存在しています：' . $employee_id);
    }

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $fields['employee_id'] = $form_state->getValue('employee_id');
    $fields['dept_code'] = $form_state->getValue('dept_code');
    $fields['name'] = $form_state->getValue('name');
    $fields['kana'] = $form_state->getValue('kana');
    $fields['position'] = $form_state->getValue('position');
    $fields['$telephone'] = $form_state->getValue('telephone');
    $fields['$mail'] = $form_state->getValue('mail');

    $query = \Drupal::database()->insert('employee');
    $query->fields($fields)->execute();


    drupal_set_message($this->t('保存しました： 社員ID ' . $fields['employee_id']));

    // 一覧のルート名を指定してリダイレクト
    $form_state->setRedirect('employee.list');

  }
}

