<?php
namespace Drupal\employee\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Url;

/**
 * Class EmployeetDeleteForm.
 *
 * @package Drupal\employee\Form
 */
class EmployeeDeleteForm extends ConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'employee_delete_form';
  }

  protected $employee_id;

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return t('社員ID：%employee_id のデータを削除します。よろしいですか？', [
      '%employee_id' => $this->employee_id,
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('employee.list');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return t('削除されたデータは元に戻すことはできません。');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return t('削除');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return t('キャンセル');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $employee_id = NULL) {

    // 引数で渡ってきた$employee_idをインスタンス変数にセット
    $this->employee_id = $employee_id;

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
    // レコードの削除
    $query = \Drupal::database();
    $query->delete('employee')->condition('employee_id', $this->employee_id)->execute();

    drupal_set_message($this->t('データが削除されました。社員ID:' . $this->employee_id));

    // 一覧のルート名を指定してリダイレクト
    $form_state->setRedirect('employee.list');
  }

}
