<?php
/**
 * @file
 * Contains \Drupal\employee\Form\EmployeeUpdateForm.
 */
namespace Drupal\employee\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Database\Database;
use Drupal\Core\Url;

class EmployeeUpdateForm extends FormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'employee_update_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $employee_id = NULL) {

    // 引数で渡された$employee_idから社員情報を取得
    $conn = Database::getConnection();
    $query = $conn->select('employee', 'emp');
    $query->condition('employee_id', $employee_id)->fields('emp');;
    $record = $query->execute()->fetchAssoc();

    $dept_code = $record['dept_code'];
    $name = $record['name'];
    $kana = $record['kana'];
    $position = $record['position'];
    $telephone = $record['telephone'];
    $mail = $record['mail'];


    $form['employee_id'] = array(
      '#type' => 'textfield',
      '#default_value' => $employee_id,
      '#title' => $this->t('社員ID'),
      '#disabled' => TRUE
    );

    $form['dept_code'] = array(
      '#type' => 'textfield',
      '#default_value' => $dept_code,
      '#title' => $this->t('部門コード'),
      '#required' => TRUE,
    );

    $form['name'] = array(
      '#type' => 'textfield',
      '#default_value' => $name,
      '#title' => $this->t('名前'),
      '#required' => TRUE,
    );

    $form['kana'] = array(
      '#type' => 'textfield',
      '#default_value' => $kana,
      '#title' => $this->t('カナ'),
      '#required' => TRUE,
    );

    $form['position'] = array(
      '#type' => 'textfield',
      '#default_value' => $position,
      '#title' => $this->t('職位'),
      '#required' => TRUE,
    );

    $form['telephone'] = array(
      '#type' => 'textfield',
      '#default_value' => $telephone,
      '#title' => $this->t('電話')
    );

    $form['mail'] = array(
      '#type' => 'textfield',
      '#default_value' => $mail,
      '#title' => $this->t('メール')
    );

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('更新'),
      '#button_type' => 'primary',
    );
    return $form;
  }

  /**
   * {@inheritdoc}
   */
    public function validateForm(array &$form, FormStateInterface $form_state) {


    }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $fields['employee_id'] = $form_state->getValue('employee_id');
    $fields['dept_code'] = $form_state->getValue('dept_code');
    $fields['name'] = $form_state->getValue('name');
    $fields['kana'] = $form_state->getValue('kana');
    $fields['position'] = $form_state->getValue('position');
    $fields['$telephone'] = $form_state->getValue('telephone');
    $fields['$mail'] = $form_state->getValue('mail');

    $query = \Drupal::database()->update('employee');
    $query->fields($fields);
    $query->condition('employee_id', $fields['employee_id']);
    $result = $query->execute();


    drupal_set_message($this->t('更新しました： 社員ID ' . $employee_id));

    // 一覧のルート名を指定してリダイレクト
    $form_state->setRedirectUrl(Url::fromRoute('employee.list'));

  }
}

